==> 0.1.3.tar.gz: ios/Classes/other/YDSucessViewController.m <==
//
//  YDSucessViewController.m
//  CLRealPersonDemo
//
//  Created by ydong on 2021/9/22.
//  Copyright © 2021 ydong. All rights reserved.
//

#import "YDSucessViewController.h"
#import <Masonry/Masonry.h>
#import "YDDemoDefines.h"
#import "UIColor+YDLiveDetect.h"

@implementation YDSucessViewController

-(void)dealloc{
    
    NSLog(@"success is dealloc");
}

- (void)viewDidLoad {
    [super viewDidLoad];
    self.title = @"认证结果";
    self.view.backgroundColor = UIColor.whiteColor;
    self.navigationItem.leftBarButtonItem = [[UIBarButtonItem alloc] initWithImage:[UIImage imageNamed:@"ico_back"] style:(UIBarButtonItemStyleDone) target:self action:@selector(back)];
    [self createSubview];
}

-(void)returnHomePage{
    
    if (self.resultCallback) {
        self.resultCallback(self.returnStr);
    }
    [self.navigationController popToRootViewControllerAnimated:YES];
}

-(void)createSubview{
    
    UIImageView *bgImage = [[UIImageView alloc] init];
    bgImage.image = [UIImage imageNamed:_isSuccess ? @"real_suc" : @"real_fail"];
    bgImage.contentMode = UIViewContentModeScaleAspectFit;
    [self.view addSubview:bgImage];
    [bgImage mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.offset(statusBarHeight+95);
        make.centerX.equalTo(self.view);
        make.width.offset(81 * KWidthScale);
        make.height.offset(95 * KWidthScale);
    }];
    
    UILabel *firstL = [[UILabel alloc] init];
    firstL.text = _isSuccess ? @"活体检测通过" : @"活体检测失败";
    firstL.font = [UIFont fontWithName:@"PingFangSC-Semibold" size:15*KWidthScale];
    firstL.textColor = [UIColor blackColor];
    firstL.textAlignment = NSTextAlignmentCenter;
    [self.view addSubview:firstL];
    [firstL mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.equalTo(bgImage.mas_bottom).offset(25 * KWidthScale);
        make.left.right.equalTo(self.view);
        make.height.offset(21);
    }];
    
    UIButton *startRealButton = [UIButton buttonWithType:UIButtonTypeCustom];
    [startRealButton setTitle:@"返回首页" forState:UIControlStateNormal];
    [startRealButton setTitleColor:UIColorFromHex(0xffffff) forState:UIControlStateNormal];
    startRealButton.titleLabel.font = [UIFont fontWithName:@"PingFangSC-Regular" size:15*KWidthScale];
    startRealButton.layer.cornerRadius = 44.0*KHeightScale/2;
    startRealButton.layer.masksToBounds = YES;
    [startRealButton setBackgroundColor:[UIColor colorWithHexString:@"#1183F7"]];
    [startRealButton addTarget:self action:@selector(returnHomePage) forControlEvents:UIControlEventTouchUpInside];
    [self.view addSubview:startRealButton];
    [startRealButton mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.equalTo(firstL.mas_bottom).offset(30*KHeightScale);
        make.centerX.equalTo(self.view);
        make.height.equalTo(@(44*KHeightScale));
        make.width.equalTo(@(311*KWidthScale));
    }];
}

-(void)back {
    [self.navigationController popToRootViewControllerAnimated:YES];
}

@end

==> 0.1.7.tar.gz: ios/Classes/other/YDSucessViewController.m <==
//
//  YDSucessViewController.m
//  
//
//  Created by ydong on 2021/9/22.
//  Copyright © 2021 ydong. All rights reserved.
//

#import "YDSucessViewController.h"
#import <Masonry/Masonry.h>
#import "YDDemoDefines.h"
#import "UIColor+YDLiveDetect.h"
#import "YDLocalizationManager.h"

@implementation YDSucessViewController

-(void)dealloc{
    
    NSLog(@"success is dealloc");
}

- (void)viewDidLoad {
    [super viewDidLoad];
    self.title = [self returnLocaleString:@"alive_result"];
    self.view.backgroundColor = UIColor.whiteColor;
    self.navigationItem.leftBarButtonItem = [[UIBarButtonItem alloc] initWithImage:[UIImage imageNamed:@""] style:(UIBarButtonItemStyleDone) target:self action:nil];
    [self createSubview];
}

//只执行一次
-(void)viewDidDisappear:(BOOL)animated{
    [super viewDidDisappear:animated];
    if (self.resultCallback) {
        self.resultCallback(self.returnStr);
    }
}

-(void)returnHomePage{
 
    [self.navigationController dismissViewControllerAnimated:YES completion:nil];
}

-(void)createSubview{
    
    UIImageView *bgImage = [[UIImageView alloc] init];
    bgImage.image = [UIImage imageNamed:_isSuccess ? @"real_suc" : @"real_fail"];
    bgImage.contentMode = UIViewContentModeScaleAspectFit;
    [self.view addSubview:bgImage];
    [bgImage mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.offset(statusBarHeight+95);
        make.centerX.equalTo(self.view);
        make.width.offset(81 * KWidthScale);
        make.height.offset(95 * KWidthScale);
    }];
    
    UILabel *firstL = [[UILabel alloc] init];
    firstL.text = [self returnLocaleString:_isSuccess ? @"alive_check_pass" : @"alive_check_fail"] ;
    firstL.font = [UIFont fontWithName:@"PingFangSC-Semibold" size:15*KWidthScale];
    firstL.textColor = [UIColor blackColor];
    firstL.textAlignment = NSTextAlignmentCenter;
    [self.view addSubview:firstL];
    [firstL mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.equalTo(bgImage.mas_bottom).offset(25 * KWidthScale);
        make.left.right.equalTo(self.view);
        make.height.offset(21);
    }];
    
    UIButton *startRealButton = [UIButton buttonWithType:UIButtonTypeCustom];
    [startRealButton setTitle:[self returnLocaleString:@"alive_return_home"] forState:UIControlStateNormal];
    [startRealButton setTitleColor:UIColorFromHex(0xffffff) forState:UIControlStateNormal];
    startRealButton.titleLabel.font = [UIFont fontWithName:@"PingFangSC-Regular" size:15*KWidthScale];
    startRealButton.layer.cornerRadius = 44.0*KHeightScale/2;
    startRealButton.layer.masksToBounds = YES;
    [startRealButton setBackgroundColor:[UIColor colorWithHexString:@"#1183F7"]];
    [startRealButton addTarget:self action:@selector(returnHomePage) forControlEvents:UIControlEventTouchUpInside];
    [self.view addSubview:startRealButton];
    [startRealButton mas_makeConstraints:^(MASConstraintMaker *make) {
        make.top.equalTo(firstL.mas_bottom).offset(30*KHeightScale);
        make.centerX.equalTo(self.view);
        make.height.equalTo(@(44*KHeightScale));
        make.width.equalTo(@(311*KWidthScale));
    }];

//    UILabel *testL = [[UILabel alloc] init];
//    testL.backgroundColor = UIColor.lightGrayColor;
//    testL.text = _returnStr;
//    testL.font = [UIFont fontWithName:@"PingFangSC-Semibold" size:15*KWidthScale];
//    testL.textColor = [UIColor blackColor];
//    testL.numberOfLines = 0;
//    [self.view addSubview:testL];
//    [testL mas_makeConstraints:^(MASConstraintMaker *make) {
//        make.top.equalTo(startRealButton.mas_bottom).offset(25 * KWidthScale);
//        make.left.offset(32);
//        make.right.offset(-32);
//        make.height.offset(160);
//    }];
}

-(NSString *)returnLocaleString:(NSString *)key{
    return [YDLocalizationManager localizedStringForKey:key language:_language];
}

@end
